@@ -55,7 +55,7 @@ import           Data.Primitive ( Prim, sizeOf )
 import           Control.Monad.Primitive
 import           Control.Monad ( liftM )
 
-import Control.DeepSeq ( NFData )
+import Control.DeepSeq ( NFData(rnf) )
 
 import Prelude hiding ( length, null, replicate, reverse, map, read,
                         take, drop, splitAt, init, tail )
@@ -67,13 +67,14 @@ import Data.Typeable ( Typeable )
 -- | Mutable vectors of primitive types.
 data MVector s a = MVector {-# UNPACK #-} !Int
                            {-# UNPACK #-} !Int
-                           {-# UNPACK #-} !(MutableByteArray s)
+                           {-# UNPACK #-} !(MutableByteArray s) -- ^ offset, length, underlying mutable byte array
         deriving ( Typeable )
 
 type IOVector = MVector RealWorld
 type STVector s = MVector s
 
-instance NFData (MVector s a)
+instance NFData (MVector s a) where
+  rnf (MVector _ _ _) = ()
 
 instance Prim a => G.MVector MVector a where
   basicLength (MVector _ n _) = n
