@@ -146,7 +146,7 @@ import Foreign.ForeignPtr
 import Foreign.Ptr
 import Foreign.Marshal.Array ( advancePtr, copyArray )
 
-import Control.DeepSeq ( NFData )
+import Control.DeepSeq ( NFData(rnf) )
 
 import Control.Monad.ST ( ST )
 import Control.Monad.Primitive
@@ -173,6 +173,10 @@ import Text.Read     ( Read(..), readListPrecDefault )
 
 import Data.Monoid   ( Monoid(..) )
 
+#if __GLASGOW_HASKELL__ >= 708
+import qualified GHC.Exts as Exts
+#endif
+
 #include "vector.h"
 
 -- | 'Storable'-based vectors
@@ -180,7 +184,8 @@ data Vector a = Vector {-# UNPACK #-} !Int
                        {-# UNPACK #-} !(ForeignPtr a)
         deriving ( Typeable )
 
-instance NFData (Vector a)
+instance NFData (Vector a) where
+  rnf (Vector _ _) = ()
 
 instance (Show a, Storable a) => Show (Vector a) where
   showsPrec = G.showsPrec
@@ -262,6 +267,16 @@ instance Storable a => Monoid (Vector a) where
   {-# INLINE mconcat #-}
   mconcat = concat
 
+#if __GLASGOW_HASKELL__ >= 708
+
+instance Storable a => Exts.IsList (Vector a) where
+  type Item (Vector a) = a
+  fromList = fromList
+  fromListN = fromListN
+  toList = toList
+
+#endif
+
 -- Length
 -- ------
 
